<?php

/*  Copyright 2009  Tim Hodson  (email : tim@timhodson.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

global $blog_in_blog_opts; 


function bib_init_opts() {
	global $blog_in_blog_opts;

	bib_set_option_default('bib_show_dots_after', 5 );
	bib_set_option_default('bib_text_delim', "," );
	bib_set_option_default('bib_text_page',  __('Page', 'blog-in-blog') );
	bib_set_option_default('bib_text_previous',  '&laquo;' );
	bib_set_option_default('bib_text_next',  '&raquo;' );
	bib_set_option_default('bib_style_selected',  'font-weight:bold;' );
	bib_set_option_default('bib_style_not_selected',  'color:grey;' );
	bib_set_option_default('bib_post_template',  'bib_post_template.tpl');
	bib_set_option_default('bib_more_link_text',  __('more', 'blog-in-blog').' &raquo;' );
	bib_set_option_default('bib_avatar_size',  96);
	bib_set_option_default('bib_hide_category_from_rss',  0);
	bib_set_option_default('bib_debug',  0);


	// always using the default Wordpress formats
	$blog_in_blog_opts['date_format'] = get_option(date_format);
	$blog_in_blog_opts['time_format'] = get_option(time_format);

}

/**
 * call bib_get_opts here to get default options set
 *  even if not using the plugin right away.
 * Makes sure that this is uptodate for the admin page
 *
 */
bib_init_opts();


function bib_set_option_default($option_name, $default) {
	global $blog_in_blog_opts;
	
	$blog_in_blog_opts[$option_name] = get_option($option_name);
	if ($blog_in_blog_opts[$option_name] == '' ) {
		$blog_in_blog_opts[$option_name] = $default;

		update_option($option_name, $blog_in_blog_opts[$option_name]);
	}
	
}

/**
 * =========================================================
 * Add options to admin menu
 */

add_option('bib_hide_category'); //??? why is this here?


add_action('admin_menu', 'blog_in_blog_menu'); // ok for 2.9

function blog_in_blog_menu() {
	add_options_page('Blog-in-Blog Options', 'Blog-in-Blog', 8, __FILE__ , 'blog_in_blog_options', 'favicon.ico');
	add_action( 'admin_init', 'register_bib_settings' );
}

function register_bib_settings() {
	//register our settings
	
	add_settings_section('bib_category_settings', __('Category Settings','blog-in-blog'), 'bib_category_section_text', 'bib_category_section');

	register_setting( 'bib-settings-group', 'bib_hide_category' );
	add_settings_field('bib_hide_category[]', __('Category id to hide from homepage','blog-in-blog') , 'bib_category_select', 'bib_category_section', 'bib_category_settings');

	register_setting( 'bib-settings-group', 'bib_hide_category_from_rss' );
	add_settings_field('bib_hide_category_from_rss',__('Hide categories from feed?', 'blog-in-blog') , 'bib_category_hide_rss_input', 'bib_category_section', 'bib_category_settings');

	add_settings_section('bib_format', __('Format Settings','blog-in-blog'), 'bib_format_section_text', 'bib_format_section');

	register_setting( 'bib-settings-group', 'bib_show_dots_after' );
	add_settings_field('bib_show_dots_after',__('Show dots (elipsis) after n pages', 'blog-in-blog') , 'bib_show_dots_input', 'bib_format_section', 'bib_format');

	register_setting( 'bib-settings-group', 'bib_text_previous' );
	add_settings_field('bib_text_previous', __('Text to show as "previous page" link', 'blog-in-blog') , 'bib_previous_link_text_input' , 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_text_next' );
	add_settings_field('bib_text_next',__('Text to show as "next page" link', 'blog-in-blog'), 'bib_next_link_text_input' , 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_text_page' );
	add_settings_field('bib_text_page',__('Text to show preceeding page 1. e.g. Post (Post 1, 2, 3) or Page (Page 1, 2, 3) etc', 'blog-in-blog'), 'bib_text_page_input' , 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_text_delim' );
	add_settings_field('bib_text_delim',__('The characters to show between page links, e.g. "," or "|"', 'blog-in-blog'), 'bib_text_delim_input' , 'bib_format_section', 'bib_format' );
	
	
	register_setting( 'bib-settings-group', 'bib_style_selected' );
	add_settings_field('bib_style_selected', __('Style for current page e.g. font-weight:bold;', 'blog-in-blog'), 'bib_style_selected_input' , 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_style_not_selected' );
	add_settings_field('bib_style_not_selected',__('Style for non current page e.g. color:grey;', 'blog-in-blog') ,'bib_style_not_selected_input' , 'bib_format_section', 'bib_format' );

	
	if( ( get_option('bib_post_template') == 'bib_post_template.tpl' ) && (! file_exists(WP_CONTENT_DIR . '/uploads/'.get_option('bib_post_template')))) {
		$template_warn_title= __('You are using the default template file', 'blog-in-blog');
		$template_warn_body= __('Any changes you make may be overwritten when a new version of the plugin is installed. You are advised to put your template file in the uploads directory. We\'ll look here first. e.g. wp-content/uploads/my_post_template.tpl', 'blog-in-blog');
		$template_warn = '<div><span style="color:red;font-weight:bold;">'.$template_warn_title.'</span> <br />'.$template_warn_body.'</div>';
	}else{
		$template_warn = "";
	}
	register_setting( 'bib-settings-group', 'bib_post_template' );
	add_settings_field('bib_post_template', __('The name of the template used to style the post. We look in wp-content/uploads/ then wp-content/plugins/blog-in-blog/ for this file. '.$template_warn, 'blog-in-blog'), 'bib_post_template_input', 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_more_link_text' );
	add_settings_field('bib_more_link_text', __('Text for the more link if you use the &lt;!--more--&gt; tag in your posts.', 'blog-in-blog'), 'bib_more_link_text_input', 'bib_format_section', 'bib_format' );

	register_setting( 'bib-settings-group', 'bib_avatar_size' );
	add_settings_field('bib_avatar_size',__('Size of the author avatar image', 'blog-in-blog') ,'bib_avatar_size_input' , 'bib_format_section', 'bib_format' );
	
	add_settings_section('bib_debug', __('Debug Settings','blog-in-blog'), 'bib_debug_section_text', 'bib_debug_section');
	
	register_setting('bib-settings-group', 'bib_debug');
	add_settings_field('bib_debug',__('Show some ugly debugging info', 'blog-in-blog') ,'bib_debug_input' , 'bib_debug_section', 'bib_debug' );
	
	

}

// category section

function bib_category_section_text()
{
	echo '<p>'.__('Define which categories should be hidden from the home page and optionally exclude them from the feeds','blog-in-blog').'</p>';
}	

function bib_category_select(){
	// categories to hide

	$select = '<select name="bib_hide_category[]" multiple="multiple" size="6" style="height:auto;">';

	$catselected = get_option('bib_hide_category');
	if (!is_array($catselected)) {
		$catselected = array($catselected);
	}
	//var_dump($catselected);

	$categories = get_categories();

	if (is_array($categories)) {

		foreach ($categories as $cat) {

			if (in_array($cat->cat_ID, $catselected)) {
				$select .= '<option value="' . $cat->cat_ID . '" selected="selected" >';
				$select .= $cat->cat_name . ' (category_id:' . $cat->cat_ID;
				$select .= ', ' . $cat->category_count . ' posts)';
				$select .= '</option>';

			} else {
				$select .= '<option value="' . $cat->cat_ID . '">';
				$select .= $cat->cat_name . ' (category_id:' . $cat->cat_ID;
				$select .= ', ' . $cat->category_count . ' posts)';
				$select .= '</option>';
			}

		}
	}
	$select .= '<option value="NONE">'.__('Show all categories', 'blog-in-blog').'</option>';
	$select .= '</select>';
	$out .= $select . '</td></tr>';
	
	echo $out;
}

function bib_category_hide_rss_input() {
	// hide categories from RSS feed
	if (get_option('bib_hide_category_from_rss')) {
		$checked = 'checked="checked""';
	}else{
		$checked = '';
	}
	
	echo '<input type="checkbox" name="bib_hide_category_from_rss" '.$checked.' />';
	
}

function bib_format_section_text() {
	echo '<p>'.__('These settings will affect how parts of the Blog-in-Blog rendered output will show across every use of the Blog-in-Blog shortcode.','bog-in-blog').'</p>';
}

function bib_show_dots_input() {
	// show dots after n pages
	echo '<input type="text" name="bib_show_dots_after" value="' . get_option('bib_show_dots_after') . '" />';
}

function bib_previous_link_text_input() {
	// previous link text
	echo '<input type="text" name="bib_text_previous" value="' . get_option('bib_text_previous') . '" />';
}

function bib_next_link_text_input() {
	// next link text
	echo '<input type="text" name="bib_text_next" value="' . get_option('bib_text_next') . '" />'	;
}

function bib_text_page_input() {
	// text preceeding page 1
	echo '<input type="text" name="bib_text_page" value="' . get_option('bib_text_page') . '" />';
}

function bib_text_delim_input(){
	// delimiter
	echo '<input type="text" name="bib_text_delim" value="' . get_option('bib_text_delim') . '" />';
}

function bib_style_selected_input() {
	// Style selected
	echo '<input type="text" name="bib_style_selected" value="' . get_option('bib_style_selected') . '" />';
}

function bib_style_not_selected_input() {
	// Style not selected
	echo '<input type="text" name="bib_style_not_selected" value="' . get_option('bib_style_not_selected') . '" />';
}

function bib_post_template_input() {
	// template file

	echo '<input type="text" name="bib_post_template" value="' . get_option('bib_post_template') . '" />';

}

function bib_more_link_text_input() {
	// more_link_text
	echo '<input type="text" name="bib_more_link_text" value="' . get_option('bib_more_link_text') . '" />';	
}

function bib_avatar_size_input() {
	// avatar image size
	echo '<input type="text" name="bib_avatar_size" value="' . get_option('bib_avatar_size') . '" />';
}

function bib_debug_section_text()
{
	echo '<p>'.__('Enable or disable debug settings','blog-in-blog').'</p>';
}

function bib_debug_input() {
	// hide categories from RSS feed
	if (get_option('bib_debug')) {
		$checked = 'checked="checked""';
	}else{
		$checked = '';
	}
	
	echo '<input type="checkbox" name="bib_debug" '.$checked.' />';
	
}




function blog_in_blog_options() {
	?>
	<div class="wrap">
	<h2>Blog-in-Blog</h2>
	<p><?php echo __('See full notes at', 'blog-in-blog') ; ?><a href="http://informationtakesover.co.uk/blog-in-blog-wordpress-plugin/">http://informationtakesover.co.uk/blog-in-blog-wordpress-plugin/</a></p>

	<form method="post" action="options.php">
	
	<?php 
	settings_fields( 'bib-settings-group' );
	do_settings_sections('bib_category_section');
	do_settings_sections('bib_format_section');
	do_settings_sections('bib_debug_section');
	?>

	<p class="submit">
	<input type="submit" class="button-primary" value="<?php _e('Save Changes'); ?>" />
	</p>

	</form>
	</div>
	
	<?php
}

?>